@@ -11,7 +11,14 @@
 
  Peter Beerli 1997, Seattle
  beerli@genetics.washington.edu
- $Id: broyden.c,v 1.50 2001/04/16 17:24:36 beerli Exp $
+<<<<<<< broyden.c
+ $Id: broyden.c,v 1.57 2001/06/04 00:08:54 beerli Exp $
+=======
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: broyden.c,v 1.57 2001/06/04 00:08:54 beerli Exp $
+>>>>>>> 1.56
 -------------------------------------------------------*/
 extern double norm (double *d, long size);
 
@@ -38,12 +45,13 @@ void gradient (double *d, nr_fmt * nr, long locus);
 double probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr);
 double
 probG2 (double *param, double *lparam, double *sm, 
-        double *kt, double *km, long *p, double *mindex, 
+        double *kt, double *km, double *p, double *mindex, 
 	int *msta, int *me, long numpop);
 void
 probG3 (double *apg, double *apg0r, timearchive_fmt *tyme, 
 	long numpop, double *apgmax,
 	double *param, double *lparam, double *sm); 
+double probG4 (double *fullparam, double *data, long numpop, long numpop2);
 double logprob_noevent (world_fmt * world, long interval);
 double sum_migprob (world_fmt * world, long pop, long interval);
 double sum_mig (double *param, long msta, long msto);
@@ -58,6 +66,7 @@ void calc_hessian (double **hess, long n, double *delta, double *gama);
 double psi (double lamda, helper_fmt * helper);
 void grad2loggrad (double *param, long *indeks, double *d, long nn, long profilenum);
 void log_param0 (double *param, double *lparam, long nn);
+void copies2lcopies(timearchive_fmt *atl);
 void create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme);
 
 
@@ -75,7 +84,7 @@ void alloc_apg(double ****apg, long repstop, long loci, long G);
 void quadratic_constants(double *xguess, 
 			 double low, double mid, double high,
 			 double xlow, double xmid, double xhigh);
-
+void symmetric_other(long i, long numpop, long *other, long *otherpop);
 double ln_copies(long n);
 
 /* Functions ++++++++++++++++++++++++++++++++++++++++++++++++*/
@@ -484,11 +493,13 @@ destroy_nr (nr_fmt * nr, world_fmt * world)
     }
   free (nr);
 }
-/*
+
 double
 calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
 {
   long g, r, j,copies;
+  long numpop = nr->world->numpop;
+  long numpop2 = nr->world->numpop2;
   int msta, msto;
   double gsum = 0;
   double ***apg0;
@@ -498,128 +509,32 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
   double *apg0r;
   timearchive_fmt tyme;
   tarchive_fmt *tl;
-  double *localparam;
   double *geo = nr->world->data->geo;
   double *lgeo = nr->world->data->lgeo;
   double *locallparam;
-  double *sm;
-  localparam = (double *) calloc((2*nr->partsize + nr->numpop),
-				 sizeof(double));
-  locallparam = localparam + nr->partsize;
-  sm = localparam + 2 * nr->partsize;
-  memcpy(localparam,param,sizeof(double)*nr->partsize);
-  memcpy(locallparam,lparam,sizeof(double)*nr->partsize);
-
-  nr->PGC[locus] = 0.0;
-  apg0 = nr->apg0;
-  // precalculations of sum(k M) and M geo
-  for(r=0;r<nr->numpop;r++)
-    {
-      msta = nr->mstart[r];
-      msto = nr->mend[r];
-      for (j = msta; j < msto; j++)
-	{
-	  sm[r] += geo[j] * localparam[j];
-	  locallparam[j] += lgeo[j];
-	}
-    }
-  // loop over replicates before normalizing
-  gsum = 0;
-  for (r = nr->repstart; r < nr->repstop; r++)
-    {
-      apg = apgall[r][locus];
-      apg0r = apg0[r][locus];
-      tyme = nr->world->atl[r][locus];
-      //first element
-      tl = &(tyme.tl[0]);
-      copies = tl->copies-1;
-      gsum += copies;
-      if(copies>0)
-	apg[0] = ln_copies(copies) + 
-	  probG2 (localparam, locallparam, sm, 
-		  tl->kt, tl->km, tl->p, 
-		  tl->mindex, 
-		  nr->mstart, nr->mend, 
-		  nr->numpop) - apg0r[0];
-      else
-	apg[0] = -DBL_MAX;
-
-      if (apg[0] > apgmax)
-	apgmax = apg[0];
-
-      //other elements
-      for (g = 1; g < tyme.T; g++)
-        {
-	  tl = &(tyme.tl[g]);
-	  copies = tl->copies;
-	  gsum += copies;
-	  apg[g] = ln_copies(copies) + 
-	    probG2 (localparam, locallparam, sm, 
-		    tl->kt, tl->km, tl->p, 
-		    tl->mindex, 
-		    nr->mstart, nr->mend, 
-		    nr->numpop) - apg0r[g];
-	  if (apg[g] > apgmax)
-	    apgmax = apg[g];
-	}
-    } // end replicates
-
-  nr->PGC[locus] = 0.0;
-  // loop over replicates normalizing
-  for (r = nr->repstart; r < nr->repstop; r++)
-    {
-      apg = nr->apg[r][locus];
-      if(apg[0] > -DBL_MAX)
-	apg[0] -= apgmax;
-      for (g = 1; g < nr->world->atl[r][locus].T; g++)
-        {
-	  apg[g] -= apgmax;
-	  if(apg[g] > -40.)
-	    nr->PGC[locus] += exp (apg[g]);
-	}
-    }
-  nr->apg_max[locus] = apgmax;
-  nr->llike = apgmax + log (nr->PGC[locus]) - log (gsum);
-  free(localparam);
-  return nr->llike;
-}
-*/
-
-double
-calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
-{
-  long g, r, j,copies;
-  int msta, msto;
-  double gsum = 0;
-  double ***apg0;
-  double apgmax = -DBL_MAX;
-  double ***apgall = nr->apg;
-  double *apg;
-  double *apg0r;
-  timearchive_fmt tyme;
-  tarchive_fmt *tl;
   double *localparam;
-  double *geo = nr->world->data->geo;
-  double *lgeo = nr->world->data->lgeo;
-  double *locallparam;
   double *sm;
-  localparam = (double *) calloc((2*nr->partsize + nr->numpop),
+  //  double temp;
+  locallparam = (double *) calloc((2*nr->partsize + numpop),
 				 sizeof(double));
-  locallparam = localparam + nr->partsize;
-  sm = localparam + 2 * nr->partsize;
-  memcpy(localparam,param,sizeof(double)*nr->partsize);
-  memcpy(locallparam,lparam,sizeof(double)*nr->partsize);
+  localparam = locallparam + numpop2;
+  
+  sm = localparam + numpop;
+  memcpy(localparam,param,sizeof(double)*numpop);
+  memcpy(locallparam,lparam,sizeof(double)*numpop2);
 
   nr->PGC[locus] = 0.0;
   apg0 = nr->apg0;
 
   for(r=0;r<nr->numpop;r++)
     {
+      locallparam[r] = LOG2 - locallparam[r];
+      localparam[r] = 1./localparam[r]; 
       msta = nr->mstart[r];
       msto = nr->mend[r];
       for (j = msta; j < msto; j++)
 	{
-	  sm[r] += geo[j] * localparam[j];
+	  sm[r] += geo[j] * param[j];
 	  locallparam[j] += lgeo[j];
 	}
     }
@@ -634,11 +549,16 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
       copies = tl->copies-1;
       gsum += copies;
       if(copies>0)
-	apg[0] = ln_copies(copies) + probG2 (localparam, locallparam, sm, 
-					     tl->kt, tl->km, tl->p, 
-					     tl->mindex, 
-					     nr->mstart, nr->mend, 
-					     nr->numpop) - apg0r[0];
+	{
+	  apg[0] = tl->lcopies + probG4 (locallparam, tl->point,numpop,numpop2) - apg0r[0];
+	  //temp = tl->lcopies + probG2 (localparam, locallparam, sm, 
+	  //	     tl->kt, tl->km, tl->p, 
+	  //	     tl->mindex, 
+	  //	     nr->mstart, nr->mend, 
+	  //	     nr->numpop) - apg0r[0];
+	  // if(temp!=apg[0])
+	  // printf("gopf");
+	}
       else
 	apg[0] = -DBL_MAX;
       if(apgmax<apg[0])
@@ -649,21 +569,24 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
 	  tl = &(tyme.tl[g]);
 	  copies = tl->copies;
 	  gsum += copies;
-	  apg[g] = ln_copies(copies) + probG2 (localparam, locallparam, sm, 
-					       tl->kt, tl->km, tl->p, 
-					       tl->mindex, 
-					       nr->mstart, nr->mend, 
-					       nr->numpop) - apg0r[g];
+	  apg[g] = tl->lcopies + probG4 (locallparam, tl->point,numpop,numpop2) - apg0r[g];
+	  //temp = tl->lcopies + probG2 (localparam, locallparam, sm, 
+	  //	       tl->kt, tl->km, tl->p, 
+	  //	       tl->mindex, 
+	  //	       nr->mstart, nr->mend, 
+	  //	       nr->numpop) - apg0r[g];
+	  //if(temp!=apg[g])
+	  //printf("gopf");
 	  if (apg[g] > apgmax)
 	    apgmax = apg[g];
 	}
-    }
+    } // end replicates
   for (r = nr->repstart; r < nr->repstop; r++)
     {
       apg = apgall[r][locus];
       apg0r = apg0[r][locus];
       tyme = nr->atl[r][locus];
-      //first element
+      // first element
       tl = &(tyme.tl[0]);
       // first element
       apg[0] -= apgmax;
@@ -678,7 +601,7 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
     } // replicates
   nr->apg_max[locus] = apgmax;
   nr->llike = apgmax + log (nr->PGC[locus]) - log (gsum);
-  free(localparam);
+  free(locallparam);
   return nr->llike;
 }
 
@@ -835,7 +758,7 @@ check_matrix_arbitrary (double *param, worldoption_fmt *wopt, long numpop)
      force_samemigration (param, wopt, numpop);
    for (i = 0; i < zeron; i++)
      {
-       param[zeros[i]] = 0.;
+       param[zeros[i]] = -30.;//-DBL_MAX;
      }
    
    for (i = 0; i < constn; i++)
@@ -875,7 +798,7 @@ check_matrix_arbitrary (double *param, worldoption_fmt *wopt, long numpop)
 void
 gradient (double *d, nr_fmt * nr, long locus)
 {
-  long z, r;
+  long z, r;//, other , otherpop;
   long g, i, ii, pop, msta, msto;
   long numpop = nr->numpop;
   long nn = nr->partsize - nr->profilenum;
@@ -906,8 +829,23 @@ gradient (double *d, nr_fmt * nr, long locus)
 	      for (i = msta; i < msto; i++)
 		{
 		  if (nr->param[i] > 0.)
-		    nr->parts[i] = ((tl[g].mindex[i] / nr->param[i]) 
-				    - geo[i] * tl[g].km[pop]);
+		    {
+		      /*if(nr->world->options->custm2[i]=='S')
+			 {
+			   symmetric_other(i, numpop, &other, &otherpop);
+			   nr->parts[i] = 
+			     (((tl[g].mindex[i] + tl[g].mindex[other]) * 
+			       nr->param[pop])/ 
+			      (nr->param[i] * nr->param[pop] + 
+			       nr->param[other] * nr->param[otherpop]) 
+			      - geo[i] * tl[g].km[pop]/2. 
+			      - geo[other] * tl[g].km[otherpop] *
+			      nr->param[pop]/(2.*nr->param[otherpop]));
+			 }
+			 else*/
+			nr->parts[i] = ((tl[g].mindex[i] / nr->param[i]) 
+					- geo[i] * tl[g].km[pop]);
+		    }
 		}
 	    }
 	  z = 0;
@@ -1049,10 +987,10 @@ check_symmetric_d (double *grad, nr_fmt * nr, long nn)
    long *consts = NULL;
    long *mms = NULL;
    long count;
-   long z = 0, i;
+   long z = 0, zz=0, i;
    char *p;
-   double mm;
-  double sign;
+   double mm, sq1, sq2;
+
 
   custm = nr->world->options->custm2;
   zeron = nr->world->options->zeron;
@@ -1094,23 +1032,74 @@ check_symmetric_d (double *grad, nr_fmt * nr, long nn)
 /* if there are symmetric migration rates M go here*/
   for (i = 0; i < symn; i++)
     {
-      mm = (grad[syms[i][0]] + grad[syms[i][1]]) / 2.;
-      grad[syms[i][0]] = grad[syms[i][1]] = mm;
+      if(nr->profilenum>0)
+	{
+	  z=0;
+	  while(nr->indeks[z] != syms[i][0] &&  z++ < nr->partsize)
+	    ;
+	  zz=0;
+	  while(nr->indeks[zz] != syms[i][1] &&  zz++ < nr->partsize)
+	    ;
+	  if(z<nr->partsize)
+	    mm = grad[z];
+	  else
+	    mm=0;
+	  if(zz<nr->partsize)
+	    mm += grad[zz];
+	  //else
+	  //  mm += 0;
+	  grad[z] = grad[zz] = mm;
+	}
+      else
+	{
+	  mm = grad[syms[i][0]] + grad[syms[i][1]];
+	  grad[syms[i][0]] = grad[syms[i][1]] = mm ;
+	}
     }
-/* if there are symmetric migration rates 4Nm TESTED?*/
-  for (i = 0; i < sym2n; i++)
+  /* if there are symmetric migration rates 4Nm*/
+  if(nr->profilenum>0)
     {
-      mm = (sqrt ((grad[sym2s[i][0]] * grad[sym2s[i][0]]) + 
-		  (grad[sym2s[i][2]] * grad[sym2s[i][2]])) + 
-	    sqrt ((grad[sym2s[i][1]] * grad[sym2s[i][1]]) + 
-		  (grad[sym2s[i][3]] * grad[sym2s[i][3]]))) / 2.;
-      mm *= mm;
-      sign = grad[sym2s[i][0]] * grad[sym2s[i][2]] < 0. ? -1. : 1.;
-      grad[sym2s[i][0]] = sqrt (mm - (grad[sym2s[i][2]] * grad[sym2s[i][2]]));
-      sign = grad[sym2s[i][1]] * grad[sym2s[i][3]] < 0. ? -1. : 1.;
-      grad[sym2s[i][1]] = sign * sqrt (mm - (grad[sym2s[i][3]] * 
-					     grad[sym2s[i][3]]));
+      for (i = 0; i < sym2n; i++)
+	{
+	  sq1 = (nr->param[sym2s[i][2]] *  nr->param[sym2s[i][2]]);
+	  sq2 = (nr->param[sym2s[i][3]] *  nr->param[sym2s[i][3]]);
+	  z=0;
+	  while(nr->indeks[z] != sym2s[i][0] &&  z++ < nr->partsize)
+	    ;
+	  zz=0;
+	  while(nr->indeks[zz] != sym2s[i][1] &&  zz++ < nr->partsize)
+	    ;
+	  if(z<nr->partsize)
+	    mm = grad[z] / sq1;
+	  else
+	    mm=0;
+	  if(zz<nr->partsize)
+	    mm += grad[zz] / sq2;
+	  //else
+	  //  mm += 0;
+	  mm /= 2.;
+	  grad[z] = mm * sq1;
+	  grad[zz] = mm * sq2;
+	}
     }
+  else
+    {
+      for (i = 0; i < sym2n; i++)
+	{
+	  sq1 = (nr->param[sym2s[i][2]] *  nr->param[sym2s[i][2]]);
+	  sq2 = (nr->param[sym2s[i][3]] *  nr->param[sym2s[i][3]]);
+	  mm = (grad[sym2s[i][0]] / sq1 + grad[sym2s[i][1]] / sq2);
+	  grad[sym2s[i][0]] = mm * sq1;
+	  grad[sym2s[i][1]] = mm * sq2;
+	}
+    }
+}
+
+void symmetric_other(long i, long numpop, long *other, long *otherpop)
+{
+  long pop;
+  m2mm(i,numpop,otherpop, &pop);
+  *other = mm2m(pop, *otherpop,numpop);
 }
 
 
@@ -1158,6 +1147,33 @@ probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr)
   return result;
 }
 
+double probG4 (double *fullparam, double *data, long numpop, long numpop2)
+{
+  int i;
+  double result = 0.;
+  // fullparam is a linearized
+  //     log(param) [size: numpop * numpop] [Log(2/theta), Log(M)]
+  //     param [thetas are 1/param] [size: numpop * numpop]
+  //     sum(migparam) [size: numpop]
+  // data is linearized
+  //     p      [size: numpop]
+  //     mindex [sizes: numpop * (numpop -1)]
+  //     kt     [size: numpop]
+  //     km     [size: numpop]
+  //
+  //  calculation: p * log(2/theta) + mindex * log(M)
+  for (i = 0; i < numpop2; i++)
+    {
+      if(fullparam[i] > -DBL_MAX)
+	result += fullparam[i] * data[i];
+    }
+  // - kt * 1/theta - km * sm
+  for (i = numpop2; i < numpop2 + 2 * numpop; i++)
+    {
+      result -= fullparam[i] * data[i];
+    }
+  return result;
+}
 
 void
 probG3 (double *apg, double *apg0r, timearchive_fmt *tyme, 
@@ -1252,7 +1268,7 @@ probG3 (double *apg, double *apg0r, timearchive_fmt *tyme,
 
 double
 probG2 (double *param, double *lparam, double *sm, 
-        double *kt, double *km, long *p, double *mindex, 
+        double *kt, double *km, double *p, double *mindex, 
 	int *msta, int *me, long numpop)
 {
   int i, j;
@@ -1261,13 +1277,14 @@ probG2 (double *param, double *lparam, double *sm,
     {
       if (lparam[i] <= -DBL_MAX)
 	return DBL_MAX;
-      result += p[i] * (LOG2 - lparam[i]);
+      //      result += p[i] * (LOG2 - lparam[i]);
       for (j = msta[i]; j < me[i]; j++)
 	{
 	  if (param[j] > 0.0)
 	      result += mindex[j] * lparam[j];
 	}
-      result += -km[i] * sm[i] - kt[i] / param[i];
+      result += p[i] * lparam[i] - km[i] * sm[i] - kt[i] * param[i];
+      //      result += -km[i] * sm[i] - kt[i] / param[i];
     }
   return result;
 }
@@ -1417,27 +1434,40 @@ log_param0 (double *param, double *lparam, long nn)
       if (param[i] > 0)
 	lparam[i] = log (param[i]);
       else
-	lparam[i] = -DBL_MAX;
+	lparam[i] = -30;//-DBL_MAX;
     }
 }
 
 
+void copies2lcopies(timearchive_fmt *atl)
+{
+  long g;
+  if(atl->tl[0].copies>1)
+    atl->tl[0].lcopies = ln_copies(atl->tl[0].copies-1);
+  else
+    atl->tl[0].lcopies = -DBL_MAX;
+  for(g=1;g<atl->T;g++)
+    {
+      atl->tl[g].lcopies = ln_copies(atl->tl[g].copies);
+    }
+}
+
 void
 create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme)
 {
   long g;
-  long copies;
+    long copies;
   /* Prob(G|Param0) */
   for (g = 0; g < tyme->T; g++)
     {
       if(g>0)
-	copies = tyme->tl[g].copies;
+      	copies = tyme->tl[g].copies;
       else
-	copies= tyme->tl[g].copies-1;
+      	copies= tyme->tl[g].copies-1;
       if(copies==0)
-	apg0[g]=-DBL_MAX;
+      	apg0[g]=-DBL_MAX;
       else
-	apg0[g] = probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr);
+      apg0[g] = probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr);
     }
 }
 
