@@ -15,7 +15,10 @@
  Peter Beerli 1996-1998, Seattle
  beerli@genetics.washington.edu
 
- $Id: combroyden2.c,v 1.68 2001/04/21 05:24:49 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: combroyden2.c,v 1.72 2001/06/02 21:40:20 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -166,7 +169,7 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt *options, dou
 	world->param0[i] = 1.;
     }
 #else
-  if (kind == MULTILOCUS)
+  if (kind == MULTILOCUS || repkind != SINGLECHAIN )
     {
       set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
       calc_meanparam (world, world->numpop2, repstart, repstop);
@@ -504,7 +507,7 @@ calc_loci_param (nr_fmt *nr, double *lparam, double *olparam, double *dv,
     }
   else
     {
-      for (i = 0, ii = 0; i < nnn - nr->profilenum; i++)
+      for (i = 0, ii = 0; i < nr->partsize - nr->profilenum; i++)
 	{
 	  ii = nr->indeks[z++];
 	  lparam[ii] =  (MAX (-30., 
@@ -1122,7 +1125,8 @@ maximize(double *param, world_fmt *world, nr_fmt *nr, long analystype, long repk
       memcpy (xv0, xv, sizeof (double) * nn);
     }
 /* end maximizer cycle ------------------------------------*/
-  finish_broyden(newL, normd, trials, world, nr, expxv, nn, analystype, repkind);
+  finish_broyden(newL, normd, trials, world, nr, expxv, nn, 
+		 analystype, repkind);
   memcpy(param, expxv,sizeof(double)*nn);
   free(hess[0]);
   free(hess);
