@@ -13,7 +13,10 @@
  
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: data.c,v 1.33 2001/04/21 05:24:49 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: data.c,v 1.35 2001/06/03 20:29:02 beerli Exp $
 
 -------------------------------------------------------*/
 #include <string.h>
@@ -249,7 +252,7 @@ void
 read_header (FILE * infile, data_fmt * data, option_fmt * options)
 {
   char input[LINESIZE], *p;
-  fgets (input, sizeof (input), infile);
+  FGETS (input, sizeof (input), infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   switch (lowercase (input[0]))
@@ -330,7 +333,7 @@ read_sites (data_fmt * data)
   long locus;
   char *input, *p, *a;
   input = (char *) calloc (LINESIZE, sizeof (char));
-  fgets (input, LINESIZE, data->infile);
+  FGETS (input, LINESIZE, data->infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   p = input;
@@ -359,7 +362,7 @@ void
 read_popheader (FILE * infile, data_fmt * data, long pop)
 {
   char input[LINESIZE], *p;
-  fgets (input, sizeof (input), infile);
+  FGETS (input, sizeof (input), infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   sscanf (input, "%ld%[^\n]", &(data->numind[pop][FLOC]), data->popnames[pop]);
@@ -427,7 +430,7 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
   a2 = (char *) calloc (1, sizeof (char) * LINESIZE);
   dlm[0] = data->dlm, dlm[1] = '\0';
   ddlm[0] = ' ', ddlm[1] = '\0';
-  fgets (input, LONGLINESIZE, infile);
+  FGETS (input, LONGLINESIZE, infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   for (locus = 0; locus < data->loci; locus++)
@@ -435,7 +438,7 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
       while (isspace ((int) *input))
 	input++;
       if (input[0] == '\0')
-	fgets (input, LONGLINESIZE, infile);
+	FGETS (input, LONGLINESIZE, infile);
       i = 0;
       while (input[i] != ' ' && input[i] != dlm[0])
 	{
@@ -482,7 +485,7 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
 
   input = (char *) calloc (1, sizeof (char) * LONGLINESIZE);
   isave = input;
-  fgets (input, LONGLINESIZE, infile);
+  FGETS (input, LONGLINESIZE, infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
   for (locus = 0; locus < data->loci; locus++)
@@ -563,18 +566,18 @@ read_distance_fromfile (FILE * dfile, long tips, long nmlength, double **m)
     {
       // assumes that the dfile is in PHYLIP format
       // and that all n x n cells are filled.
-      fgets (input, LINESIZE, dfile);	//reads header line with
+      FGETS (input, LINESIZE, dfile);	//reads header line with
       for (i = 0; i < tips; i++)	// of individuals
 	{
 	  //reads header line with
-	  fgets (input, nmlength + 1, dfile);
+	  FGETS (input, nmlength + 1, dfile);
 	  for (j = 0; j < tips; j++)
 	    {
 	      fscanf (dfile, "%lf", &m[i][j]);
 	    }
 	  // reads the last \n from the
 	  // data matrix
-	  fgets (input, LINESIZE, dfile);
+	  FGETS (input, LINESIZE, dfile);
 	}
     }
 }
@@ -592,7 +595,7 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep, long *u
     {
       // assumes that the uepfile is in PHYLIP format
       // and that all n cells are filled.
-      fgets (input, LINESIZE, uepfile);	//reads header line with
+      FGETS (input, LINESIZE, uepfile);	//reads header line with
       // of individuals and uep sites
       sscanf (input, "%li%li", &thistips, uepsites);
       if (thistips != tips)
@@ -602,11 +605,11 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep, long *u
 	  for (i = 0; i < tips; i++)
 	    {
 	      uep[i] = (long *) calloc (*uepsites, sizeof (long));
-	      fgets (input, nmlength + 1, uepfile);  //reads each line
+	      FGETS (input, nmlength + 1, uepfile);  //reads each line
 	      for (j = 0; j < *uepsites; ++j)
 		fscanf (uepfile, "%li", &uep[i][j]);
 	      // reads the last \n from the data matrix
-	      fgets (input, LINESIZE, uepfile);
+	      FGETS (input, LINESIZE, uepfile);
 	    }
 	}
       else
@@ -615,14 +618,14 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, long **uep, long *u
 	    {
 	      uep[i] = (long *) calloc (*uepsites, sizeof (long));
 	      uep[i+tips] = (long *) calloc (*uepsites, sizeof (long));
-	      fgets (input, nmlength + 1, uepfile);  //reads each line
+	      FGETS (input, nmlength + 1, uepfile);  //reads each line
 	      for (j = 0; j < *uepsites; ++j)
 		fscanf (uepfile, "%li", &uep[i][j]);
 	      // finished reading first allele, no onto the second
 	      for (j = 0; j < *uepsites; ++j)
 		fscanf (uepfile, "%li", &uep[i+tips][j]);
 	      // reads the last \n from the data matrix
-	      fgets (input, LINESIZE, uepfile);
+	      FGETS (input, LINESIZE, uepfile);
 	    }
 	}
     }
