@@ -14,12 +14,15 @@
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
 
-  $Id: definitions.h,v 1.58 2001/04/28 07:03:42 beerli Exp $
+  
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: definitions.h,v 1.63 2001/07/16 16:03:21 beerli Exp $
 
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.1"
+#define MIGRATEVERSION "1.2"
 #endif
 
 #define MAINTAINER "Peter Beerli <beerli@genetics.washington.edu>"
@@ -34,6 +37,8 @@
 #undef sun
 #endif
 
+#define FGETS  myfgets
+
 #ifdef __MWERKS__
 #include "conf.h"
 #undef HAVE_LGAMMA
@@ -159,11 +164,13 @@ typedef unsigned char boolean;
 #define DEFAULT_POPNMLENGTH  100	/* length of world names */
 #define NUMPOP 2
 #define BURNINPERIOD 10000
+#define SCALEINTERVAL 5
 /* don't change below here ------------------------------------
    some other constants */
 /* numerical borders and epsilons*/
 #define SMALL_VALUE       10e-21
 #define EPSILON         0.000001	/* a small number */
+#define EPSILON4        0.000099	/* another small number */
 #define SMALLEPSILON       1e-15 	/* a smaller number */
 #define BIGEPSILON         0.001	/* a not so small number */
 #define LONGCHAINEPSILON  10e100	/* an unreasonable big number, 
@@ -318,6 +325,7 @@ typedef unsigned char boolean;
 #define MAXCATEGS              9
 #define MANYCATEGS             2
 #define ONECATEG               1
+
 #ifdef MEMDEBUG
 #include <memdebug.h>
 #endif
