@@ -126,9 +126,9 @@ void gamma_loci_derivative(helper_fmt *helper)
 void  gamma_locus_derivative(helper_fmt *helper, long locus)
 {
   long r, i, ii,z;
-  long double **temp, *tempmax;
-  long double ll;
-  long double sumi;
+  double **temp, *tempmax;
+  double ll;
+  double sumi;
   int **stemp;
   //double *summll;
   //double summllsum;
@@ -142,9 +142,9 @@ void  gamma_locus_derivative(helper_fmt *helper, long locus)
   double theta1 = helper->expxv[0];
   long partsize = nr->partsize;
   //summll = (double *) calloc(GAMMA_INTERVALS, sizeof(double));
-  tempmax = (long double *) calloc(partsize, sizeof(long double));
-  temp = (long double **) calloc(partsize, sizeof(long double*));
-  temp[0] = (long double *) calloc(partsize * GAMMA_INTERVALS, sizeof(long double));
+  tempmax = ( double *) calloc(partsize, sizeof( double));
+  temp = ( double **) calloc(partsize, sizeof( double*));
+  temp[0] = ( double *) calloc(partsize * GAMMA_INTERVALS, sizeof( double));
   stemp = (int **) calloc(partsize, sizeof(int*));
   stemp[0] = (int *) calloc(partsize * GAMMA_INTERVALS, sizeof(int));
   tempmax[0]= -DBL_MAX;
