@@ -14,7 +14,10 @@
                                                                                                                
  Peter Beerli, started 1997, Seattle
  beerli@genetics.washington.edu
-$Id: main.c,v 1.69 2001/05/17 05:46:48 beerli Exp $
+
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: main.c,v 1.74 2001/07/02 21:30:30 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -61,7 +64,8 @@ tpool_t heating_pool;
 #endif
 
 char appl[20];
-longer seed;
+long * seed;
+long * newseed;
 
 int setup_locus (long locus, world_fmt * world, option_fmt * options,
 		 data_fmt * data);
@@ -170,6 +174,10 @@ main (int argc, char **argv)
   myID = MASTER;
   numcpu = 1;
 #endif
+  // random number seed global inits
+  seed = malloc(sizeof(long) * 3);
+  newseed = malloc(sizeof(long) * 3);
+  // 
   universe = (world_fmt **) calloc (HEATED_CHAIN_NUM, sizeof (world_fmt *));
   this_string = (char *) calloc (1, sizeof (char) * 256);
   strcpy (appl, "Migrate");
@@ -233,33 +241,17 @@ main (int argc, char **argv)
 #ifdef MPI
   if (myID == MASTER)
     {
-      //mpi_send_stop (EARTH);
-      //printf ("%i> stop sent\n", myID);
 #endif
       print_list (EARTH, options, data);
       fflush (EARTH->outfile);
-      //printf ("%i> stopping result workers\n", myID);
-      //mpi_results_stop ();
 #ifdef MPI
     }
-      //else
-      // {
-      /*worker code; master is in print_result_population */
-      //maxreplicate = (options->replicate ? 
-      //		      ((options->replicatenum > 0) ?
-      //	       options->replicatenum+1 : options->lchains+1) :
-      //	      1 );
-      //printf ("waiting for print instruction\n");
-      //fflush (stdout);
-      //mpi_results_worker (EARTH->atl, maxreplicate, EARTH->numpop, EARTH->who);
-      //}
 #endif
   if(options->aic || (EARTH->options->lratio->counter > 0))
     {
 #ifdef MPI
       if (myID == MASTER)
 	{
-	  //	  mpi_gmax_master(EARTH, Gmax);
 #endif
 	  if (EARTH->options->lratio->counter > 0)
 	    print_lratio_test (EARTH, &Gmax);
@@ -267,13 +259,6 @@ main (int argc, char **argv)
 	    akaike_information(EARTH, &Gmax);
 #ifdef MPI
 	}
-      //else
-      //	{
-	  //printf("%i> before gmax worker\n",myID);
-	  //mpi_gmax_worker (EARTH);
-      //	  printf("%i> start worker postlike calculations\n",myID);
-      //	  mpi_maximize_worker (EARTH, options->replicatenum);
-      //	}
 #endif
     }
   print_mighist (EARTH);      
@@ -283,38 +268,39 @@ main (int argc, char **argv)
     analyze_uep (EARTH);
 #endif
   /* profile tables --------------------------------------------- */
-#ifdef MPI
+#ifdef SLOWNET /*DOES NOT WORK YET*/
+  // if there are many loci but only few parameters to estimate
+  // this will be still slow and saturating the network
+  // may still be te better solution
+  if(myID == MASTER)
+    {
+      mpi_send_stop (EARTH); // stop workers
+    }
+  distribute_treedata(EARTH); //distributes to all numcpu all the treesummaries
+  profile_tables (options, EARTH, &Gmax); 
+#else
+#ifdef MPI  /*WORKS*/
   if (myID == MASTER)
     {
-      //   printf ("%i> start profile tables\n", myID);
-      //mpi_gmax_master (EARTH, &Gmax);
 #endif
       profile_tables (options, EARTH, &Gmax);
 #ifdef MPI
-      //      printf("%i> finished percentile tables\n",myID);
     }
-  //else
-  // {
-  //  printf("%i> start worker profile calculations\n",myID);
-  //  //mpi_gmax_worker (EARTH);
-  //mpi_maximize_worker (EARTH, options->replicatenum);
-  //}
-#endif
+#endif 
+#endif /*SLOWNET*/
   if (myID == MASTER)
     {
-      //      printf("%i> closing up\n",myID);
       print_finish (EARTH, outfilepos);
       /* closing all files ------------------------------------------ */
 #ifdef MAC
       finish_mac (options, data);
 #endif
       exit_files (EARTH, data, options);
-      //      printf("%i> closing up, after print_finish\n",myID);fflush(stdout);
     }
-  //else
-    //    printf("%i> closing up\n",myID);
 #ifdef MPI
+#ifndef SLOWNET
   mpi_send_stop (EARTH); // stop workers
+#endif
   MPI_Finalize ();
 #endif
   apocalypse_now(EARTH);
@@ -326,6 +312,12 @@ main (int argc, char **argv)
 void
 combine_loci (char type, option_fmt * options, world_fmt * world, long *Gmax)
 {
+  long kind = MULTILOCUS;
+  if(options->readsum)
+    {
+      if(world->loci==1)
+	kind=SINGLELOCUS;
+    }
   if ((world->loci - world->skipped > 1) || (options->readsum))
     {
       if(options->gamma)
@@ -338,15 +330,15 @@ combine_loci (char type, option_fmt * options, world_fmt * world, long *Gmax)
 #endif
 	  estimateParameter (options->replicatenum, *Gmax, world,
 			     options, world->cov[world->loci], 0 /*chain */ ,
-			     type, MULTILOCUS,
+			     type, kind,
 			     world->repkind);	
 #ifdef MPI
 	}
       else
 	{
-	  //	  printf("%i> before gmax worker\n",myID);
+	  printf("%i> before gmax worker\n",myID);
 	  mpi_gmax_worker (world);
-	  //	  printf("%i> start worker postlike calculations\n",myID);
+	  printf("%i> start worker postlike calculations\n",myID);
 	  mpi_maximize_worker (world, options->replicatenum);
 	}
 #endif
@@ -412,7 +404,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #ifdef MPI
   if (myID == MASTER)
     {
-      mpi_runloci_master (data, EARTH->who);
+      mpi_runloci_master (data->loci, EARTH->who);
     }
   else
     {
@@ -846,9 +838,21 @@ analyze_olddata (world_fmt * world,
       world->options->plotnow = TRUE;
     }
   world->locus = 0;
-  *outfilepos = print_title (world, options);
-  print_options (stdout, world, options, data);
-  print_options (world->outfile, world, options, data);
+  if(myID==MASTER)
+    {
+      *outfilepos = print_title (world, options);
+      print_options (stdout, world, options, data);
+      print_options (world->outfile, world, options, data);
+#ifdef MPI
+      mpi_runloci_master(world->loci, world->who);
+#endif
+    }
+#ifdef MPI
+  else
+    {
+      assignloci_worker(world);
+    }
+#endif
   return Gmax;
 }
 
