@@ -8,7 +8,14 @@
  presents the menu and its submenus.                                                                                                               
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: menu.c,v 1.46 2001/05/10 06:50:07 beerli Exp $
+<<<<<<< menu.c
+ $Id: menu.c,v 1.49 2001/06/04 00:08:54 beerli Exp $
+=======
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+>>>>>>> 1.47
+
+$Id: menu.c,v 1.49 2001/06/04 00:08:54 beerli Exp $
 
 -------------------------------------------------------*/
 #include "migration.h"
@@ -169,7 +176,7 @@ get_menu (option_fmt * options)
 	  printf ("\n\n");
 	  printf ("  Are the settings correct?\n");
 	  printf ("  (Type Y or the letter for one to change)\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch (uppercase (input[0]))
 	    {
 	    case 'D':
@@ -343,7 +350,7 @@ menuData (option_fmt * options, char datatype[])
       printf ("  Are the settings correct?\n");
       printf ("  (Type Y or the number of the entry to change)\n");
       input[0] = '\0';
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       if(strlen(input)==0)
 	continue;
       switch (atol(input))
@@ -374,7 +381,7 @@ menuData (option_fmt * options, char datatype[])
 	      printf ("  of 0.0 (ZERO) to go to 13 (39),\n");
 	      printf ("  if you choose this too small, than the program will fail\n");
 	      printf ("  [the bigger the longer the run and the more\n accurate the estimate]\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->micro_threshold = atof(input);
 	      input[0]='\0';
 	      break;
@@ -451,7 +458,7 @@ menuData (option_fmt * options, char datatype[])
 	      break;
 	    case 9:
 	      fprintf (stdout, "Enter the sequencing error rate per site\n[Good values are 0.0 (=no error), or 0.01 (1%% error):\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->seqerror = atof(input);
 	      input[0]='\0';
 	      break;
@@ -638,13 +645,13 @@ menuInput (option_fmt * options)
 #endif
       printf ("\n\n  Are the settings correct?\n");
       printf ("  (type Y to go back to the main menu or the letter for the entry to change)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       test = atoi (input);
       switch (test)
 	{
 	case 1:
 	  printf ("  What is the datafile name?\n[Default: %s]\n", INFILE);
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (input[0] == '\n')
 	    strcpy (options->infilename, INFILE);
 	  else
@@ -658,7 +665,7 @@ menuInput (option_fmt * options)
 	    {
 	      printf ("  (A)utomatic or (S)eedfile or (O)wn\n");
 	      printf ("  Start value for Random-generator seed\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      switch (uppercase (input[0]))
 		{
 		case 'A':
@@ -692,7 +699,7 @@ menuInput (option_fmt * options)
 	  break;
 	case 3:
 	  printf ("  Enter a title? [max 80 Characters are used]\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (input[0] == '\0')
 	    options->title[0] = '\0';
 	  else
@@ -700,7 +707,7 @@ menuInput (option_fmt * options)
 	  break;
 	case 4:
 	  printf (" What is the filename for the summary of genealogies\n[Default: %s]\n", SUMFILE);
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (input[0] == '\n')
 	    strcpy (options->sumfilename, SUMFILE);
 	  else
@@ -711,7 +718,7 @@ menuInput (option_fmt * options)
 	  break;
 	case 5:
 	  printf ("  Progress report during the run? <YES | Verbose | No>\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch (tolower (input[0]))
 	    {
 	    case 'n':
@@ -736,7 +743,7 @@ menuInput (option_fmt * options)
 	  break;
 	case 7:
 	  printf ("  What is the output filename?\n[Default: %s]\n", OUTFILE);
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (input[0] == '\n')
 	    strcpy (options->outfilename, OUTFILE);
 	  else
@@ -753,7 +760,7 @@ menuInput (option_fmt * options)
 		{
 		  printf ("  Plot Likelihood surface:\n");
 		  printf ("  (B)oth to outfile and mathfile, (O)utfile only, (N)o plot\n");
-		  fgets (input, LINESIZE, stdin);
+		  FGETS (input, LINESIZE, stdin);
 		}
 	      while (strchr ("BON", (int) uppercase (input[0])) == NULL);
 	      switch (uppercase (input[0]))
@@ -778,20 +785,20 @@ menuInput (option_fmt * options)
 		      printf ("              Ranges: X-%5.5s: %f - %f\n", options->plotvar == PLOT4NM ? "4Nm" : "M", options->plotrange[0], options->plotrange[1]);
 		      printf ("              Ranges: Y-%5.5s: %f - %f\n", "Theta", options->plotrange[2], options->plotrange[3]);
 		      printf (" Is this OK? [Yes or No]\n");
-		      fgets (input, LINESIZE, stdin);
+		      FGETS (input, LINESIZE, stdin);
 		      answer = uppercase (input[0]);
 		      if (answer != 'Y')
 			{
 			  printf ("1    Use as X-axis: 4Nm  Y-axis: Theta\n");
 			  printf ("2    Use as X-axis: M    Y-axis: Theta\n");
-			  fgets (input, LINESIZE, stdin);
+			  FGETS (input, LINESIZE, stdin);
 			  if (input[0] == '2')
 			    options->plotvar = PLOTM;
 			  else
 			    options->plotvar = PLOT4NM;
 			  printf ("1     Scale is standard \n");
 			  printf ("2     Scale is in Log10\n");
-			  fgets (input, LINESIZE, stdin);
+			  FGETS (input, LINESIZE, stdin);
 			  if (input[0] == '2')
 			    options->plotscale = PLOTSCALELOG;
 			  else
@@ -800,7 +807,7 @@ menuInput (option_fmt * options)
 			    {
 			      printf ("How many plot positions?\n");
 			      printf ("[Default is 36, this changes only in the mathfile]\n");
-			      fgets (input, LINESIZE, stdin);
+			      FGETS (input, LINESIZE, stdin);
 			      if (strlen (input) > 1)
 				options->plotintervals = ATOL (input);
 			    }
@@ -809,11 +816,11 @@ menuInput (option_fmt * options)
 			  printf ("              Ranges: X-%5.5s: %f - %f\n", options->plotvar == PLOT4NM ? "4Nm" : "M", options->plotrange[0], options->plotrange[1]);
 			  printf ("              Ranges: Y-%5.5s: %f - %f\n", "Theta", options->plotrange[2], options->plotrange[3]);
 			  printf ("Give lowest and highest value for X axis:\n");
-			  fgets (input, LINESIZE, stdin);
+			  FGETS (input, LINESIZE, stdin);
 			  if (strlen (input) > 1)
 			    sscanf (input, "%lf%lf", &options->plotrange[0], &options->plotrange[1]);
 			  printf ("Give lowest and highest value for Y axis:\n");
-			  fgets (input, LINESIZE, stdin);
+			  FGETS (input, LINESIZE, stdin);
 			  if (strlen (input) > 1)
 			    sscanf (input, "%lf%lf", &options->plotrange[2], &options->plotrange[3]);
 			}
@@ -828,7 +835,7 @@ menuInput (option_fmt * options)
 	    {
 	      printf ("  Evaluate profile likelihoods:\n");
 	      printf ("  (N)o, (A)all [Tables and Summary],\n  (T)ables, (S)ummary\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	    }
 	  while (strchr ("NATS", (int) uppercase (input[0])) == NULL);
 	  switch (uppercase (input[0]))
@@ -859,7 +866,7 @@ menuInput (option_fmt * options)
 		  printf ("  (D)iscrete   : evaluation at (0.02, 0.05, 0.1, .. , 50)*ML estimate\n");
 		  printf ("  (Q)uick      : Assuming parameters are indepenent\n");
 
-		  fgets (input, LINESIZE, stdin);
+		  FGETS (input, LINESIZE, stdin);
 		}
 	      while (strchr ("pdqf", (int) lowercase (input[0])) == NULL);
 	      switch (lowercase (input[0]))	// in strchr removed s
@@ -897,7 +904,7 @@ menuInput (option_fmt * options)
 	    {
 	      printf ("  Print genealogies:\n");
 	      printf ("  (N)one, (A)all [!], (B)est, (L)ast chain\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	    }
 	  while (strchr ("NABL", (int) uppercase (input[0])) == NULL);
 	  switch (uppercase (input[0]))
@@ -921,7 +928,7 @@ menuInput (option_fmt * options)
 	  break;
 	case 12:
 	  printf ("  What is the plot coordinate filename?\n[Default: %s]\n", MATHFILE);
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (input[0] == '\n')
 	    strcpy (options->mathfilename, MATHFILE);
 	  else
@@ -932,12 +939,12 @@ menuInput (option_fmt * options)
 	  break;
 	case 13:
 	  printf (" Save genealogy summaries? [No]\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (toupper (input[0]) == 'Y')
 	    {
 	      options->writesum = TRUE;
 	      printf (" What is the filename for the summary of genealogies\n[Default: %s]\n", SUMFILE);
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      if (input[0] == '\n')
 		strcpy (options->sumfilename, SUMFILE);
 	      else
@@ -954,12 +961,12 @@ menuInput (option_fmt * options)
 	  break;
 	case 14:
 	  printf (" Save logging information? [No]\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (toupper (input[0]) == 'Y')
 	    {
 	      options->writelog = TRUE;
 	      printf (" What is the filename for logging\n[Default: %s]\n", LOGFILE);
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      if (input[0] == '\n')
 		strcpy (options->logfilename, LOGFILE);
 	      else
@@ -977,12 +984,12 @@ menuInput (option_fmt * options)
 #ifdef UEP
 	case 15:
 	  printf (" UEP estimation? [No]\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  if (toupper (input[0]) == 'Y')
 	    {
 	      options->uep = TRUE;
 	      printf (" What is the filename of the UEP data\n[Default: %s]\n", UEPFILE);
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      if (input[0] == '\n')
 		strcpy (options->uepfilename, UEPFILE);
 	      else
@@ -1003,7 +1010,7 @@ menuInput (option_fmt * options)
 	      fprintf(stdout,"What is mutation rate for the UEP locus\n");
 	      fprintf(stdout,"[expressed as a ratio of the point mutation rate\n");
 	      fprintf(stdout, "Reasonable values are 0.0 =< x <=1.0]\n");
-	      fgets(input,LINESIZE,stdin);
+	      FGETS(input,LINESIZE,stdin);
 	      options->ueprate = atof(input);
 	    } while (options->ueprate < 0.0);
 	  break;
@@ -1069,8 +1076,14 @@ menuParameters (option_fmt * options)
       if (options->migrguess == FST || options->thetaguess == FST)
 	{
 	  printf ("\n\n  FST-CALCULATION (for start value)\n  ----------------------------------\n");
-	  printf ("  4       %s\n", options->fsttype == 'T' ? "Variable Theta, M symmetric" : "Variable M, Theta is the same for all populations");
-	  printf ("  5       Print FST table in %s: %s\n", options->outfilename, options->printfst ? "Yes" : "No");
+	  printf ("  4       %s\n", 
+		  options->fsttype == 'T' ? 
+		  "Variable Theta, M symmetric" : 
+		  "Variable M, Theta is the same for all populations");
+	  printf ("  5       Print FST table in %s: %s\n", 
+		  options->outfilename, options->printfst ? 
+		  "Yes" : 
+		  "No");
 	}
       strcpy (custmexplain, custom_migration_type (options->migration_model));
 
@@ -1079,12 +1092,12 @@ menuParameters (option_fmt * options)
       printf ("  7       Geographic distance matrix: %s\n", options->geo ? "Yes" : "No");
       printf ("\n\n  Are the settings correct?\n");
       printf ("  (Type Y to go back to the main menu or the letter for an entry to change)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       switch (input[0])
 	{
 	case '1':
 	  printf ("  Which method? (F)st or (O)wn or (R)andom value\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch(uppercase (input[0]))
 	    {
 	    case 'R':
@@ -1123,7 +1136,7 @@ menuParameters (option_fmt * options)
 	  break;
 	case '2':
 	  printf ("Which method?  (F)st or (O)wn or (R)andom value\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch (uppercase (input[0]))
 	    {
 	    case 'R':
@@ -1152,7 +1165,6 @@ menuParameters (option_fmt * options)
 		    {
 		      if (j == i)
 			{
-			  tt++;
 			  printf ("Population %3li              > --\n", i + 1);
 			  continue;
 			}
@@ -1163,7 +1175,7 @@ menuParameters (option_fmt * options)
 			break;
 		    }
 		}
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->nummg = tt;
 	      tt = 0;
 	      printf ("\n     You typed in the following migration matrix\n\n     ");
@@ -1175,7 +1187,6 @@ menuParameters (option_fmt * options)
 			printf ("%5.2f ", options->mg[tt++]);
 		      else
 			{
-			  tt++;
 			  printf ("----- ");
 			}
 		    }
@@ -1201,7 +1212,7 @@ menuParameters (option_fmt * options)
 	  printf ("(M)igration rate can be asymmetric\n");
 	  printf ("   and Theta is the same for both populations\n");
 	  printf ("   (Number of populations = 2)\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch (uppercase (input[0]))
 	    {
 	    case 'M':
@@ -1252,14 +1263,14 @@ menuStrategy (option_fmt * options)
 	}
       printf ("\n\n  Are the settings correct?\n");
       printf ("  (Type Y to go back to the main menu or the letter for an entry to change)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       switch (atoi (input))
 	{
 	case 1:
 	  do
 	    {
 	      printf ("  How many Short Chains?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->schains = atoi (input);
 	      if (options->schains < 0)
 		printf ("  Must be non-negative\n");
@@ -1270,7 +1281,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many trees to skip?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->sincrement = atoi (input);
 	      if (options->sincrement <= 0)
 		printf ("  Must be positive\n");
@@ -1281,7 +1292,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many trees to sample?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->ssteps = atoi (input);
 	      if (options->ssteps <= 0)
 		printf ("  Must be a positive integer\n");
@@ -1292,7 +1303,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many Long Chains?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->lchains = atoi (input);
 	      if (options->lchains < 0)
 		printf ("  Must be non-negative\n");
@@ -1303,7 +1314,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many trees to skip?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->lincrement = atoi (input);
 	      if (options->lincrement <= 0)
 		printf ("  Must be positive\n");
@@ -1314,7 +1325,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many trees to sample?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->lsteps = atoi (input);
 	      if (options->lsteps <= 0)
 		printf ("  Must be a positive integer\n");
@@ -1325,7 +1336,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  How many genealogies to discard?\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->burn_in = atoi (input);
 	      if (options->burn_in <= 0)
 		printf ("  Must be a positive integer or zero (0)\n");
@@ -1341,11 +1352,11 @@ menuStrategy (option_fmt * options)
 		  printf ("  Summarize over (L)ong chains?\n");
 		  printf ("  or (M)ultiple runs ?\n");
 		  printf ("  [Default is (L)]\n");
-		  fgets (input, LINESIZE, stdin);
+		  FGETS (input, LINESIZE, stdin);
 		  if (uppercase (input[0]) == 'M')
 		    {
 		      printf ("  How many independent runs\n");
-		      fgets (input, LINESIZE, stdin);
+		      FGETS (input, LINESIZE, stdin);
 		      options->replicatenum = ATOL (input);
 		      if (options->lcepsilon < 0)
 			printf ("  Enter a number >= 1\n");
@@ -1362,7 +1373,7 @@ menuStrategy (option_fmt * options)
 	  break;
 	case 9:
 	  printf ("  Heating scheme? < NO | YES | (p)arallele chains | #heating_intervals (=YES)>\n");
-	  fgets (input, LINESIZE, stdin);
+	  FGETS (input, LINESIZE, stdin);
 	  switch (tolower (input[0]))
 	    {
 	    case 'p':
@@ -1387,7 +1398,7 @@ menuStrategy (option_fmt * options)
 	  if (options->heating > 0)
 	    {
 	      fprintf (stdout, "Enter the number of different \"heated\" chains.\nMinimum is 4\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      options->heated_chains = atol (input);
 	      if (options->heated_chains < 4)
 		options->heated_chains = HEATED_CHAIN_NUM;
@@ -1402,7 +1413,7 @@ menuStrategy (option_fmt * options)
 		{
 		  printf ("  How big should the fraction of new genealogies\n");
 		  printf ("  of the originally proposed number of samples be?\n");
-		  fgets (input, LINESIZE, stdin);
+		  FGETS (input, LINESIZE, stdin);
 		  options->acceptfreq = atof (input);
 		  if (options->acceptfreq < 0)
 		    printf ("  Range should be between 0 - 1, and not %f\n", options->acceptfreq);
@@ -1414,7 +1425,7 @@ menuStrategy (option_fmt * options)
 	  do
 	    {
 	      printf ("  Parameter likelihood epsilon?\n[INF is Default]\n");
-	      fgets (input, LINESIZE, stdin);
+	      FGETS (input, LINESIZE, stdin);
 	      if(uppercase(input[0])=='I')
 		options->lcepsilon =  LONGCHAINEPSILON;
 	      else
@@ -1528,7 +1539,7 @@ char ask_lratio_type(lr_data_fmt *data, long counter)
   char input[LINESIZE];
   printf ("  Is the test against the Maximum likelihood estimates or\n");
   printf("   or against arbitrary values? [(M)LE, (A)rbitrary]\n");
-  fgets (input, 1024, stdin);
+  FGETS (input, 1024, stdin);
   switch (uppercase (input[0]))
     {
     case 'M':
@@ -1590,7 +1601,7 @@ void how_many_pop(long *numpop)
       do
 	{
 	  printf ("  How many populations?\n");
-	  fgets (input, 1024, stdin);
+	  FGETS (input, 1024, stdin);
 	  *numpop = atoi (input);
 	}
       while (*numpop <= 0 && *numpop < 100);
@@ -1628,7 +1639,7 @@ char menuread_lrt_paramvalue(char *value, long *counter, long numpop2)
   char input[LINESIZE];
   while (z < numpop2)
     {
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       temp = strtok (input, ", \n\t");
       if (temp != NULL)
 	{
@@ -1713,7 +1724,7 @@ read_custom_menu_migration (option_fmt * options)
   printf ("  Enter now the values:\n");
   while (z < numpop2)
     {
-      fgets (input, 1024, stdin);
+      FGETS (input, 1024, stdin);
       read_custom_migration (stdin, options, input, numpop);
       z = (long) strlen (options->custm);
     }
@@ -1771,7 +1782,7 @@ read_heatvalues (option_fmt * options)
   fprintf (stdout, "or give a range of values [exponential increase: 1 @ 10]\n");
   fprintf (stdout, "The coldest, which is the first, has to be 1\n");
   fprintf (stdout, "[For example: 1 1.5 3 6]\n");
-  fgets (input, LINESIZE, stdin);
+  FGETS (input, LINESIZE, stdin);
   if (strstr (input, "-"))
     {
       tmp = strstr (input, "-");
@@ -1814,7 +1825,7 @@ read_heatvalues (option_fmt * options)
 		  if (z < options->heated_chains)
 		    {
 		      fprintf (stdout, "%li more values are needed\n", options->heated_chains - z);
-		      fgets (input, LINESIZE, stdin);
+		      FGETS (input, LINESIZE, stdin);
 		      tmp = strtok (input, " ,");
 		      if (tmp != NULL)
 			{
@@ -1832,7 +1843,7 @@ read_heatvalues (option_fmt * options)
   for (i = options->heated_chains - 1; i >= 0; --i)
     fprintf (stdout, "%4li             %f\n", i, options->heat[i]);
   fprintf (stdout, "\n\nIs this correct? [Yes or No]\n");
-  fgets (input, LINESIZE, stdin);
+  FGETS (input, LINESIZE, stdin);
   if ('y' != tolower (input[0]))
     read_heatvalues (options);
 }
@@ -1860,7 +1871,7 @@ void	  start_tree_method(option_fmt *options)
 		     "daur" : "dar"));
   do
     {
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
     }
   while (strchr (compstring, (int) (lowercase (input[0]))) == NULL);
   switch (lowercase (input[0]))
@@ -1900,7 +1911,7 @@ void start_data_method(option_fmt *options)
       printf ("  (n)ucleotide polymorphism (SNP)\n");
       printf ("  (u)nlinked nucleotide polymorphism (SNP) using a PANEL\n");
       printf ("  (g)enealogy summaries\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
     }
   while (strchr ("ambnsguf", (int) (lowercase (input[0]))) == NULL);
   options->datatype = input[0];
