@@ -10,15 +10,17 @@
  presents the menu and its submenus.                                                                                                               
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: menu.h,v 1.2 2000/07/26 23:03:20 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: menu.h,v 1.5 2001/06/02 21:40:21 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
 
 extern void print_menu_title (FILE * file, option_fmt * options);
 extern void print_menu_accratio (FILE * file, long a, long b);
-extern long print_title (world_fmt * world);
+extern long print_title (world_fmt * world, option_fmt *options);
 extern void get_menu (option_fmt * options);
 
 #endif /*MENU_INCLUDE */
-
