@@ -20,7 +20,7 @@ extern int locidone;
 
 extern void broadcast_options(option_fmt *options);
 
-extern void mpi_runloci_master(data_fmt * data, int *who);
+extern void mpi_runloci_master(long loci, int *who);
 
 extern void mpi_runloci_worker(world_fmt ** universe, int usize, 
 		       option_fmt * options, data_fmt * data, 
@@ -52,6 +52,7 @@ extern void mpi_gmax_worker(world_fmt *world);
 
 extern void mpi_send_stop(world_fmt *world);
 extern void mpi_results_stop(void);
+extern void assignloci_worker(world_fmt *world);
 #endif
 #endif
 
