@@ -778,6 +778,9 @@ typedef struct _aic_fmt {
   char *pattern;
   long numparam;
   double mle;
+  double lrt;
+  double prob;
+  double probcorr;
 } aic_fmt;
 
 
@@ -790,13 +793,9 @@ typedef struct _aic_fmt {
 /* global variables (this should be not used at all) */
 extern char appl[20];
 
-#ifdef HIGHBITS
 typedef long longer[3];		/* used in random.c */
-extern long seed[3];
-#else
-typedef long longer[6];
-extern long seed[6];
-#endif
+extern long *seed;
+extern long *newseed;
 
 #include "tools.h"
 #include "sort.h"
