@@ -13,7 +13,10 @@
  
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: options.c,v 1.76 2001/05/01 16:36:09 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: options.c,v 1.78 2001/06/03 20:29:02 beerli Exp $
 -------------------------------------------------------*/
 //#include <stdio.h>
 #include <time.h>
@@ -108,7 +111,7 @@ init_options (option_fmt * options)
   options->nmlength = DEFAULT_NMLENGTH;
   options->popnmlength = DEFAULT_POPNMLENGTH;
   options->allelenmlength = DEFAULT_ALLELENMLENGTH;
-  options->custm = (char *) calloc (1, sizeof (char) * (1 + NUMPOP));
+  options->custm = (char *) calloc (1, sizeof (char) * 1000);//needs fix
   //options->custm2 = (char *) calloc (1, sizeof (char) * (1 + NUMPOP));
   options->symn = 0;
   options->sym2n = 0;
@@ -275,7 +278,7 @@ read_options_master (option_fmt * options)
     {
       counter = 0;
       position = ftell (options->parmfile);
-      while (fgets (input, LINESIZE, options->parmfile) != NULL)
+      while (FGETS (input, LINESIZE, options->parmfile) != NULL)
 	{
 	  counter++;
 	  if ((input[0] == '#') || isspace ((int) input[0]) || input[0] == ';')
@@ -3070,7 +3073,7 @@ read_custom_migration (FILE * file, option_fmt * options, char *value, long cust
 	  z = 0;
 	  if (file == stdin)
 	    printf ("Enter the next value or list of values\n");
-	  fgets (value, LINESIZE, file);
+	  FGETS (value, LINESIZE, file);
 	  break;
 	default:
 	  options->custm = (char *) realloc (options->custm, sizeof (char) * (zz + 2));
@@ -3120,7 +3123,7 @@ read_custom_migration (FILE * file, option_fmt * options, char *value, long cust
   while (file != stdin && !(strstr (value, "end") || strchr (value, '=')))
     {
       position = ftell (options->parmfile);
-      fgets (value, LINESIZE, file);
+      FGETS (value, LINESIZE, file);
     }
   if (file != stdin)
     reset_oneline (options, position);
