@@ -13,7 +13,10 @@
                                                                                                                
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: random.c,v 1.22 2001/04/09 17:14:49 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: random.c,v 1.24 2001/06/04 00:08:54 beerli Exp $
 -------------------------------------------------------*/
 
 #include "sighandler.h"
@@ -39,7 +42,7 @@ extern tpool_t heating_pool;
 
 /* prototypes ----------------------------------------- */
 void getseed (option_fmt * options);
-void swap_ptr(void * ptr, void * newptr);
+void swap_ptr(long ** ptr, long ** newptr);
 
 double randum (void);
 #ifdef PTHREADS
@@ -50,6 +53,9 @@ double randum_thread (void);
 void
 getseed (option_fmt * options)
 {
+#ifdef MPI
+  long test;
+#endif
 #ifndef SPRNG
   long i;
 #endif
@@ -84,9 +90,41 @@ getseed (option_fmt * options)
       error ("Error: Seed value not defined");
       break;
     }
+#ifndef SPRNG
 #ifdef MPI
-  options->inseed = abs(options->inseed + (myID * 100000.));
+  MPI_Bcast(&options->inseed, 1, MPI_LONG, MASTER, MPI_COMM_WORLD);
+  if(myID!=MASTER)
+    {
+      for (i = 1; i <= 1000; i++)	/* clear the random number generator */
+	RANDUM ();
+      
+      for (i = 0; i <= 2; i++)
+	seed[i] = 0;
+      i = 0;
+      do
+	{
+	  seed[i] = options->inseed & 2047;
+	  options->inseed /= 2048;
+	  i++;
+	}
+      while (options->inseed != 0);
+      
+      for(i=0; i < myID; i++)
+	{
+	  test = RANDINT(1,MAXLONG);
+	  //printf("     %i %li> %li\n", myID, i, test); 
+	}
+      switch(test % 4)
+	{
+	case 0: test++; break;
+	case 1: break;
+	case 2: test--; break;
+	case 3: test--; test--; break;
+	}
+      options->inseed = test;
+    }
   printf("%i> random number seed = %li\n", myID, options->inseed); 
+#endif
 #endif
   options->saveseed = options->inseed;
 #ifdef SPRNG
@@ -108,12 +146,12 @@ getseed (option_fmt * options)
 #endif /* not SPRNG*/
 }
 
-void   swap_ptr(void * ptr, void * newptr)
+void   swap_ptr(long ** ptr, long ** newptr)
 {
-  void * temp;
-  temp = ptr;
-  ptr = newptr;
-  newptr = temp;
+  long * temp;
+  temp = *ptr;
+  *ptr = *newptr;
+  *newptr = temp;
 }
 
 #ifdef PTHREADS
@@ -125,7 +163,7 @@ randum_thread (void)
   return sprng();
 #else
   double value;
-  longer newseed;
+  //longer newseed;
 #ifdef PTHREADS
   if ((pthread_mutex_lock (&(heating_pool->random_lock))) != 0)
     error ("pthread_mutex_lock failed in random_thread()");
@@ -139,8 +177,8 @@ randum_thread (void)
   newseed[2] += newseed[1] / 2048;
   newseed[1] &= 2047;
   newseed[2] += 1549 * seed[2] + 812 * seed[1];
-
-  memcpy (seed, newseed, sizeof (longer));
+  swap_ptr(&newseed, &seed);
+  //  memcpy (seed, newseed, sizeof (longer));
   seed[2] &= 1023;
   value = (((seed[0] / 2048.0 + seed[1]) / 2048.0 + seed[2]) / 1024.0);
 #ifdef PTHREADS
@@ -159,7 +197,7 @@ randum (void)
   return sprng();
 #else
   double value;
-  longer newseed;
+  //  longer newseed;
   newseed[0] = 1549 * seed[0];
   newseed[1] = newseed[0] / 2048;
   newseed[0] &= 2047;
@@ -169,8 +207,8 @@ randum (void)
   newseed[2] += newseed[1] / 2048;
   newseed[1] &= 2047;
   newseed[2] += 1549 * seed[2] + 812 * seed[1];
-  memcpy (seed, newseed, sizeof (longer));
-  //swap_ptr(&seed,&newseed);
+  //memcpy (seed, newseed, sizeof (longer));
+  swap_ptr(&newseed, &seed);
   seed[2] &= 1023;
   value = (((seed[0] / 2048.0 + seed[1]) / 2048.0 + seed[2]) / 1024.0);
   return value;
