@@ -9,7 +9,14 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: sequence.c,v 1.32 2001/01/08 17:40:07 beerli Exp $
+<<<<<<< sequence.c
+ $Id: sequence.c,v 1.36 2001/06/04 00:08:54 beerli Exp $
+=======
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+>>>>>>> 1.34
+
+$Id: sequence.c,v 1.36 2001/06/04 00:08:54 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -25,7 +32,7 @@ void init_sequences2 (world_fmt * world, seqmodel_fmt * seq, long locus);
 void initratio (option_fmt * options);
 void initfreqs (double *freqa, double *freqc, double *freqg, double *freqt);
 void initcatn (long *categs);
-boolean initcategs (long categs, double *rate);
+boolean initcategs (long categs, double *rate, double *probcat);
 void initprobcat (long categs, double *probsum, double *probcat);
 void init_tbl (world_fmt * world, long locus);
 void print_weights (FILE * outfile, world_fmt * world, option_fmt * options, long locus);
@@ -111,7 +118,7 @@ initratio (option_fmt * options)
   char *tmp;
   char input[LINESIZE];
   printf ("Transition/transversion ratio?\nEnter a value for each locus, spaced by blanks or commas\n");
-  fgets (input, LINESIZE, stdin);
+  FGETS (input, LINESIZE, stdin);
   tmp = strtok (input, " ,\n");
   while (tmp != NULL)
     {
@@ -132,7 +139,7 @@ initfreqs (double *freqa, double *freqc, double *freqg, double *freqt)
   printf ("Base frequencies for A, C, G, T/U\n (use blanks to separate, if all are equal use a sign [=])?\n");
   for (;;)
     {
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       if (input[0] == '=')
 	{
 	  scanned = 4;
@@ -171,8 +178,8 @@ initcatn (long *categs)
 }
 
 
-boolean initcategs (long categs, double *rate)
-{				/* initialize category rates */
+boolean initcategs (long categs, double *rate, double *probcat)
+{				/* initialize rate categories*/
   long i;
   char input[LINESIZE];
   char rest[LINESIZE];
@@ -182,11 +189,11 @@ boolean initcategs (long categs, double *rate)
   for (;;)
     {
       printf ("Either enter the Shape parameter alpha for Gamma deviated rates\n*OR* enter the rates for each category (use a space to separate)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       done = TRUE;
       if (count_words (input) == 1)
 	{
-	  gamma_rates (rate, categs, input);
+	  gamma_rates (rate, probcat, categs, input);
 	  return TRUE;
 	}
       for (i = 0; i < categs; i++)
@@ -220,7 +227,7 @@ initprobcat (long categs, double *probsum, double *probcat)
     {
       printf ("Probability for each category?");
       printf (" (use a space to separate)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       done = TRUE;
       for (i = 0; i < categs; i++)
 	{
