@@ -206,6 +206,27 @@ sig_error (char string[], char filename[], long line)
   exit (-11);
 }
 
+char * myfgets(char *buffer, long bufsize, FILE *infile)
+{
+  long count=0;
+  char ch='\0';
+  bufsize--;
+  while(!(ch=='\r' || ch=='\n') && count < bufsize)
+    {
+      ch = fgetc(infile);
+      buffer[count] = ch;
+      count++;
+    }
+  //buffer[count]=ch;
+  if(ch=='\r')
+  {
+    ch = fgetc(infile);
+    if (ch!='\n')
+      ungetc(ch,infile);
+  }
+  buffer[count-1]='\0';
+  return buffer;
+}
 
 #ifdef NEXTAPP
 void
@@ -290,3 +311,4 @@ LAMARC_realloc (void *ptr, const unsigned long size, const char file[], const lo
 
 
 #endif /*LAMARC_MALLOC */
+
