@@ -11,8 +11,10 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: tools.c,v 1.40 2001/04/21 05:24:50 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
 
+$Id: tools.c,v 1.47 2001/07/02 21:30:30 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "data.h"
@@ -21,6 +23,7 @@
 #include "broyden.h"
 #include "migrate_mpi.h"
 #include "options.h"
+#include "laguerre.h"
 
 #include <math.h>
 #ifdef DMALLOC_FUNC_CHECK
@@ -46,7 +49,7 @@ char uppercase (char c);
 double sum (double *vector, long n);
 void bootstrap (world_fmt * world);
 
-void gamma_rates (double *rate, long categs, char *input);
+void gamma_rates (double *rate, double *probcat, long categs, char *input);
 void calc_gamma (double alpha, double *gama, long categs);
 
 double mylgamma (double z);
@@ -104,6 +107,9 @@ double find_chi (long df, double prob);
 double probchi (long df, double chi);
 double chisquare (long df, double alpha);
 
+double
+chiboundary (long zeros, long nonzeros, double alpha);
+
 /* vector initialization */
 void doublevec1d(double **v, long size)
 {
@@ -379,7 +385,7 @@ openfile (FILE ** fp, char *filename, char *mode, const char *application, char
 	      while (file[0] == '\0')
 		{
 		  printf ("Please enter a new filename for reading>");
-		  fgets (file, LINESIZE, stdin);
+		  FGETS (file, LINESIZE, stdin);
 		}
 	      break;
 	    case 'w':
@@ -388,7 +394,7 @@ openfile (FILE ** fp, char *filename, char *mode, const char *application, char
 	      while (file[0] == '\0')
 		{
 		  printf ("Please enter a new filename for writing>");
-		  fgets (file, LINESIZE, stdin);
+		  FGETS (file, LINESIZE, stdin);
 		}
 	      break;
 	    }
@@ -422,14 +428,14 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
   double tmpm;
   boolean newstyle = TRUE;
 
-  fgets (input, 1024, sumfile);
+  FGETS (input, 1024, sumfile);
   if (!strncmp ("# begin genealogy-summary file of migrate", input, 41))
     {
-      fgets (input, 1024, sumfile);
+      FGETS (input, 1024, sumfile);
       if (input[0] == '#')
 	{
 	  newstyle = TRUE;
-	  fgets (input, 1024, sumfile);
+	  FGETS (input, 1024, sumfile);
 	}
       else
 	newstyle = FALSE;
@@ -459,7 +465,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
       for (l = 0; l < world->loci; l++)
 	for (r = 0; r < nrep; r++)
 	  {
-	    fgets (input, 1024, sumfile);
+	    FGETS (input, 1024, sumfile);
 	    fscanf (sumfile, "%li %li %li\n", &ta[r][l].T, &ta[r][l].numpop, &ta[r][l].sumtips);
 	    Gmax = (ta[r][l].T > Gmax) ? ta[r][l].T : Gmax;
 	    ta[r][l].allocT = 0;
@@ -470,7 +476,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 		fscanf (sumfile, "%li ", &ta[r][l].tl[i].copies);
 		for (j = 0; j < world->numpop; j++)
 		  {
-		    fscanf (sumfile, "%lf %lf %li\n", &ta[r][l].tl[i].km[j], &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
+		    fscanf (sumfile, "%lf %lf %lf\n", &ta[r][l].tl[i].km[j], &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
 		  }
 		if (newstyle)
 		  {
@@ -505,7 +511,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
 	    //  {
 	    //    fscanf(sumfile,"%lg ",&ta[l].likelihood[i]);
 	    //  }
-	    //      fgets(input,1024,sumfile);
+	    //      FGETS(input,1024,sumfile);
 	    fscanf (sumfile, "%li %lg\n", &ta[r][l].trials, &ta[r][l].normd);
 	  }
     }
@@ -546,7 +552,7 @@ write_savesum (world_fmt * world)
 	      fprintf (sumfile, "%li ", ta[r][l].tl[i].copies);
 	      for (j = 0; j < world->numpop; j++)
 		{
-		  fprintf (sumfile, "%20.20f %20.20f %li\n", ta[r][l].tl[i].km[j], ta[r][l].tl[i].kt[j], ta[r][l].tl[i].p[j]);
+		  fprintf (sumfile, "%20.20f %20.20f %f\n", ta[r][l].tl[i].km[j], ta[r][l].tl[i].kt[j], ta[r][l].tl[i].p[j]);
 		}
 	      for (j = 0; j < world->numpop2; j++)
 		{
@@ -1817,7 +1823,6 @@ uppercase (char c)
 double
 find_chi (long df, double prob)
 {
-
   double a, b, m;
   double xb = 200.0;
   double xa = 0.0;
@@ -1850,7 +1855,7 @@ probchi (long df, double chi)
 {
   double prob;
   double v = ((double) df) / 2.;
-  if (chi > DBL_EPSILON)
+  if (chi > DBL_EPSILON && v > DBL_EPSILON)
     {
       //lg = exp (LGAMMA (v));
       prob = 1. - incompletegamma (chi / 2., v);
@@ -1863,6 +1868,62 @@ probchi (long df, double chi)
   return prob;
 }
 
+double probchiboundary(double chi, long zeros, long all)
+{
+  double a, b, m;
+  double xb = 1.0;//1.0-EPSILON/1000.;
+  double xa = 0.0;//EPSILON/1000.;
+  double xm = 0.51;
+  double nonzeros = all - zeros;
+  if(zeros==0)
+    {
+      return probchi(all,chi);
+    }
+  a = chiboundary (zeros, nonzeros, xa);
+  m = chiboundary (zeros, nonzeros, xm);
+  b = chiboundary (zeros, nonzeros, xb);
+  while (fabs (m - chi) > EPSILON && (fabs(xa-xm)>EPSILON && fabs(xb-xm)>EPSILON))
+    {
+      if (m < chi)
+	{
+	  b = m;
+	  xb = xm;
+	}
+      else
+	{
+	  a = m;
+	  xa = xm;
+	}
+      xm = /*(-(b * xa) + chi * xa + a * xb - chi * xb) / (a - b);	*/(xa + xb)/2.;
+
+      m = chiboundary (zeros, nonzeros, xm);
+    }
+  return xm;
+}
+
+double
+chiboundary (long zeros, long nonzeros, double alpha)
+{
+  //  double prob;
+  double sum=0.;
+  long i;
+  long k=zeros;
+  double freq;
+  double summ;
+  //printf("z=%li a=%4.2f ", k,alpha);
+  for(i=0;i<=zeros;i++)
+    {
+      //      sum = zerovec[i] 	* (i+nonzeros) == 0 ? 0. : find_chi(i+nonzeros,alpha);
+      freq = exp(logfac(k)-logfac(k-i)-logfac(i)-LOG2*k);
+      summ = (i+nonzeros) == 0 ? 0. : find_chi(i+nonzeros,alpha);
+      //      printf(" %.2f(%.4f)",freq*pow(2.,k),summ);
+      sum += freq * summ;
+    }
+  //printf("\n");
+  return sum;
+}
+
+
 double
 chisquare (long df, double alpha)
 {
@@ -2015,15 +2076,21 @@ m2mml2 (long i, long topop, long numpop)
 
 
 void
-gamma_rates (double *rate, long categs, char *input)
+gamma_rates (double *rate, double *probcat, long categs, char *input)
 {
+  long i;
   double alpha = DBL_MAX;
   double value;
   while (!isdigit (*input) && *input != '\0')
     input++;
   if ((value = strtod (input, (char **) NULL)) > 0)
     alpha = value;
-  calc_gamma (alpha, rate, categs);
+  initgammacat(categs,alpha,1.,rate,probcat);
+  for (i = 0; i < categs; i++)
+    {
+      probcat[i] = exp(probcat[i]);
+    }
+  //  calc_gamma (alpha, rate, categs);
 }
 
 /* calculation of rate values following a gamma distribution for
@@ -2075,7 +2142,7 @@ calc_gamma (double alpha, double *gama, long categs)
 	}
       gama[i] = x / alpha;
 //Debug
-      fprintf (stderr, "  %li> %f\n", i, gama[i]);
+//      fprintf (stderr, "  %li> %f\n", i, gama[i]);
 
       if (x >= 10e10)
 	{
