@@ -10,7 +10,10 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: tools.h,v 1.15 2001/05/17 05:46:48 beerli Exp $
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: tools.h,v 1.16 2001/06/02 21:40:21 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -29,7 +32,7 @@ extern void invert_matrix (double **a, long nsize);
 extern boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton);
 extern double rannor (double mean, double sd);
 extern double find_chi (long df, double prob);
-extern double probchiboundary(double chi, long zeros, long nonzeros);
+extern double probchiboundary(double chi, long zeros, long all);
 extern double chiboundary (long zeros, long nonzeros, double alpha);
 extern double probchi (long df, double chi);
 extern double chisquare (long df, double alpha);
