@@ -26,6 +26,65 @@ void print_ancestor(FILE *out, world_fmt *world, long copies);
 void update_uepanc(world_fmt *world);
 void check_uep_root(node *p, world_fmt *world);
 
+void twostate_nuview(node * mother, world_fmt * world, const long locus)
+{
+  node *d1 = NULL, *d2 = NULL;
+  long a, aa;
+  double w1, w2, v1, v2;
+  double pija1, pija2, lx1, lx2;
+  double test = 0.0;
+  double *xx1, *xx2;
+  double xx3[2];
+
+  children (mother, &d1, &d2);
+  xx1 = d1->ux.a;
+  xx2 = d2->ux.a;
+  v1 = 1 - exp (-d1->v);
+  v2 = 1 - exp (-d2->v);
+  if (v1 >= 1.)
+    {
+      w1 = 0.0;
+      v1 = 1.0;
+    }
+  else
+    {
+      w1 = 1.0 - v1;
+    }
+  if (v2 >= 1.)
+    {
+      w2 = 0.0;
+      v2 = 1.0;
+    }
+  else
+    {
+      w2 = 1.0 - v2;
+    }
+  
+
+  for (aa = 0; aa < 2; aa++)
+    {
+      pija1 = pija2 = 0.0;
+      for (a = 0; a < mal - 1; a++)
+	{
+	  pija1 += ((aa == a) * w1 + v1 * freq) * xx1[a];
+	  pija2 += ((aa == a) * w2 + v2 * freq) * xx2[a];
+	}
+      pija1 += ((aa == a) * w1 + v1 * freql) * xx1[a];
+      pija2 += ((aa == a) * w2 + v2 * freql) * xx2[a];
+      xx3[aa] = pija1 * pija2;
+      test += xx3[aa];
+      if (xx3[aa] > x3m)
+	x3m = xx3[aa];
+
+    }
+  for (aa = 0; aa < 2; aa++)
+    {
+      xx3[aa] /= x3m;
+    }
+  mother->scale[0] = log (x3m) + lx2 + lx1;
+  memcpy (mother->x.a, xx3, sizeof (double) * 2);
+}
+
 void
 alloc_uepanc (long ***uepanc, long size, long numpop, long loci)
 {
